import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import { useState, useEffect } from 'react';
import { getI18n, getDefaults } from './context';
import { warnOnce } from '../utils';

function loadNamespaces(i18n, ns, cb) {
  i18n.loadNamespaces(ns, function () {
    // delay ready if not yet initialized i18n instance
    if (i18n.isInitialized) {
      cb();
    } else {
      var initialized = function initialized() {
        // due to emitter removing issue in i18next we need to delay remove
        setImmediate(function () {
          i18n.off('initialized', initialized);
        });
        cb();
      };

      i18n.on('initialized', initialized);
    }
  });
}

export function useT(ns) {
  // assert we have the needed i18nInstance
  var i18n = getI18n();

  if (!i18n) {
    warnOnce('You will need pass in an i18next instance by using i18nextReactModule');
    return [function (k) {
      return k;
    }, false, {}];
  }

  var i18nOptions = getDefaults(); // prepare having a namespace

  var namespaces = ns || i18n.options && i18n.options.defaultNS;
  namespaces = typeof namespaces === 'string' ? [namespaces] : namespaces || ['translation']; // are we ready? yes if all namespaces in first language are loaded already (either with data or empty objedt on failed load)

  var ready = i18n.isInitialized && namespaces.every(function (n) {
    return i18n.hasResourceBundle(i18n.languages[0], n);
  }); // set states

  var _useState = useState(!!ready),
      _useState2 = _slicedToArray(_useState, 2),
      isReady = _useState2[0],
      setIsReady = _useState2[1];

  var _useState3 = useState({
    t: i18n.getFixedT(null, namespaces[0])
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      t = _useState4[0],
      setT = _useState4[1]; // seems we can't have functions as value -> wrap it in obj


  function resetT() {
    setT({
      t: i18n.getFixedT(null, namespaces[0])
    });
  }

  useEffect(function () {
    // not yet loaded namespaces -> load them
    if (!isReady) loadNamespaces(i18n, namespaces, function () {
      resetT();
      setIsReady(true);
    }); // bind events to trigger change, like languageChanged

    if (i18nOptions.bindI18n && i18n) i18n.on(i18nOptions.bindI18n, resetT); // unbinding

    return function () {
      if (i18nOptions.bindI18n) {
        var p = i18nOptions.bindI18n.split(' ');
        p.forEach(function (f) {
          return i18n.off(f, resetT);
        });
      }
    };
  });
  return [t.t, isReady, i18n];
}